Module class

Module class 

Types and traits used for registering classes with PHP.

Structs

ClassMetadata
Stores the class entry, handlers, and property descriptors for a Rust type which has been exported to PHP. Usually allocated statically.
ConstructorMeta
Stores metadata about a classes Rust constructor, including the function pointer and the arguments of the function.

Enums

ConstructorResult
Result returned from a constructor of a class.

Traits

RegisteredClass
Implemented on Rust types which are exported to PHP. Allows users to get and set PHP properties on the object.

Type Aliases

ClassEntryInfo
A type alias for a tuple containing a function pointer to a class entry and a string representing the class name used in stubs.