IntoZendObject

Trait IntoZendObject 

pub trait IntoZendObject {
    // Required method
    fn into_zend_object(self) -> Result<ZBox<ZendObject>>;
}
Implemented on types which can be converted into a Zend object. It is up to the implementation to determine the type of object which is produced.

Required Methods

fn into_zend_object(self) -> Result<ZBox<ZendObject>>

Attempts to convert self into a Zend object.

Errors

If the conversion fails, an Error is returned.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl IntoZendObject for Closure

Available on crate feature closure only.
Source

impl<T> IntoZendObject for T

Available on crate feature enum only.